#!/bin/bash



#get all parameters needed
while getopts ":f:r:dsh" opt; do
  case $opt in
    \?)
	echo "Builds all equivalent TDRL rearrangements for genomes that can transformed into each other by one TDRL."
	echo "usage: ./build_figures.sh -f <filename> [-g <restriction_filename>]"
	echo "-f file: file containing the genomes"
	echo "-r file: file containing the restrictions on all TDRL operations"
	echo "-d duplicated genes are marked (default: disabled)"
	echo "-s show orientation of the genes (default: disabled)"
	echo "-h help: prints this message"
      exit 1
      ;;
    :)
      echo "Option -$OPTARG requires an argument." >&2
      exit 1
      ;;
    f)
      file=$OPTARG
      ;;
    r)
      rfile=$OPTARG
      ;;
    d)
      duplication=true
      ;;
    s)
      see_sign=true
      ;;
    h)
	echo "Builds all equivalent TDRL rearrangements for genomes that can transformed into each other by one TDRL."
	echo "usage: ./build_figures.sh -f <filename> [-g <restriction_filename>]"
	echo "-f file: file containing the gene orders"
	echo "-r file: file containing the restrictions on all TDRL operations"
	echo "-d duplicated genes are marked (default: disabled)"
	echo "-s show orientation of the genes (default: disabled)"
	echo "-h help: prints this message"
      exit 1
      ;;     
  esac
done

echo $name
# check if filename is given
if [ -z "$file" ]
then
	echo "File name must be given! --> exiting"
	exit 1
fi

echo "*****************************************************************************"
echo "calculate TDRL scenarios ..."
if [ -z "$rfile" ]
then
	if [ -z "$duplication" ]
	then
		if [ -z "$see_sign" ]
		then
			./tdrl_pic -f $file
		else
			./tdrl_pic -f $file -s
		fi
	else
		if [ -z "$see_sign" ]
		then
			./tdrl_pic -f $file -d
		else
			./tdrl_pic -f $file -d -s
		fi
	fi
else
	if [ -z "$duplication" ]
	then
		if [ -z "$see_sign" ]
		then
			./tdrl_pic -f $file -r $rfile
		else
			./tdrl_pic -f $file -r $rfile -s
		fi
	else
		if [ -z "$see_sign" ]
		then
			./tdrl_pic -f $file -r $rfile -d
		else
			./tdrl_pic -f $file -r $rfile -d -s
		fi
	fi
fi

echo "*****************************************************************************"
filebuilt=$(ls |grep .dat| wc -l)

echo $filebuilt

if  [ $filebuilt -gt 0 ]
then
	echo "build figures ..."
	for i in *.rR
	do
		Rscript $i
	done

	echo "number of figures built: $filebuilt"
else
	echo "Input genomes are equal, all TDRL distances are larger than one or the restrictions do not allow a feasible TDRL rearrangement."
fi

echo "*****************************************************************************"
echo "remove temporary files"

for i in *.rR
do
	rm $i
done
for i in *.dat
do
	rm $i
done

